@@ -40,7 +40,7 @@ def preprocess(DIR, classes, name, resized_size=224, train_size=None):
 
                     train.append([gray, classNum])
                     count +=1 
-                    print(f'{_printTotal(count)} - {item}')
+                    _printTotal(count, item)
                 else:
                     break
 
@@ -58,8 +58,8 @@ def preprocess(DIR, classes, name, resized_size=224, train_size=None):
     #Returns Training Set
     return train
 
-def _printTotal(count):
-    print(count)
+def _printTotal(count, category):
+    print(f'{_printTotal(count)} - {category}')
 
 def shuffle(train):
     """
